@@ -287,6 +287,9 @@ class GSPeerConnectionBroadcasterPiSocketv2:
         self.oncommand = oncommand
         self.setChannel = setChannel
         # picam.append(camera)
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+
         if self.gsdbs.credentials["stunenable"]:
             self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
         if self.gsdbs.credentials["turnenable"]:
